=================================
Django Babel Underscore Extractor
=================================

.. image:: https://badge.fury.io/py/django-babel-underscore.png
    :target: http://badge.fury.io/py/django-babel-underscore

.. image:: https://travis-ci.org/EnTeQuAk/django-babel-underscore.png?branch=master
        :target: https://travis-ci.org/EnTeQuAk/django-babel-underscore

.. image:: https://pypip.in/d/django-babel-underscore/badge.png
        :target: https://pypi.python.org/pypi/django-babel-underscore


Implements a underscore extractor for django-babel.

* Free software: BSD license
* Documentation: http://django-babel-underscore.readthedocs.org.

Features
--------

* TODO
